@@ -1,54 +1,48 @@
+import logging
+import typing
+
+import requests
+
 from .settings import (
-    BASE_URL,
+    BALANCE_SHEET_STATEMENT_AS_REPORTED_FILENAME,
+    BALANCE_SHEET_STATEMENT_FILENAME,
+    CASH_FLOW_STATEMENT_AS_REPORTED_FILENAME,
+    CASH_FLOW_STATEMENT_FILENAME,
     DEFAULT_LIMIT,
     FINANCIAL_STATEMENT_FILENAME,
-    CASH_FLOW_STATEMENT_FILENAME,
-    INCOME_STATEMENT_FILENAME,
-    BALANCE_SHEET_STATEMENT_FILENAME,
     INCOME_STATEMENT_AS_REPORTED_FILENAME,
-    BALANCE_SHEET_STATEMENT_AS_REPORTED_FILENAME,
-    CASH_FLOW_STATEMENT_AS_REPORTED_FILENAME,
+    INCOME_STATEMENT_FILENAME,
+    BASE_URL_v3,
 )
-from .general_methods import __quote
 from .url_methods import (
-    __return_json,
-    __validate_sector,
-    __validate_period,
-    __validate_industry,
+    __return_json_v3,
     __validate_exchange,
+    __validate_industry,
+    __validate_period,
+    __validate_sector,
+    __return_json_v4,
 )
-import requests
-import typing
-import logging
 
 
-def company_profile(apikey: str, symbol: str) -> typing.List[typing.Dict]:
+def company_profile(
+    apikey: str, symbol: str
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /profile/ API.
 
     Gather this company's information.
     :param apikey: Your API key.
     :param symbol: Ticker of Company.
-   """
-    path = f"profile/{symbol}"
-    query_vars = {"apikey": apikey}
-    return __return_json(path=path, query_vars=query_vars)
-
-
-def company_quote(
-    apikey: str, symbol: typing.Union[str, typing.List]
-) -> typing.List[typing.Dict]:
-    """
-    Query FMP /quote/ API
-
-    :param apikey: Your API key
-    :param symbol: Company ticker or tickers
     :return: A list of dictionaries.
     """
-    return __quote(apikey=apikey, value=symbol)
+    path = f"profile/{symbol}"
+    query_vars = {"apikey": apikey}
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
-def key_executives(apikey: str, symbol: str) -> typing.List[typing.Dict]:
+def key_executives(
+    apikey: str, symbol: str
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /key-executives/ API.
 
@@ -59,12 +53,12 @@ def key_executives(apikey: str, symbol: str) -> typing.List[typing.Dict]:
     """
     path = f"key-executives/{symbol}"
     query_vars = {"apikey": apikey}
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def search(
     apikey: str, query: str = "", limit: int = DEFAULT_LIMIT, exchange: str = ""
-) -> typing.List[typing.Dict]:
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /search/ API.
 
@@ -82,12 +76,12 @@ def search(
         "query": query,
         "exchange": __validate_exchange(value=exchange),
     }
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def search_ticker(
     apikey: str, query: str = "", limit: int = DEFAULT_LIMIT, exchange: str = ""
-) -> typing.List[typing.Dict]:
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /search-ticker/ API.
 
@@ -105,7 +99,7 @@ def search_ticker(
         "query": query,
         "exchange": __validate_exchange(value=exchange),
     }
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def financial_statement(
@@ -125,7 +119,7 @@ def financial_statement(
         "apikey": apikey,
         "datatype": "zip",  # Only ZIP format is supported.
     }
-    response = requests.get(f"{BASE_URL}{path}", params=query_vars)
+    response = requests.get(f"{BASE_URL_v3}{path}", params=query_vars)
     open(filename, "wb").write(response.content)
     logging.info(f"Saving {symbol} financial statement as {filename}.")
 
@@ -154,11 +148,11 @@ def income_statement(
     query_vars = {"apikey": apikey, "limit": limit, "period": __validate_period(period)}
     if download:
         query_vars["datatype"] = "csv"  # Only CSV is supported.
-        response = requests.get(f"{BASE_URL}{path}", params=query_vars)
+        response = requests.get(f"{BASE_URL_v3}{path}", params=query_vars)
         open(filename, "wb").write(response.content)
         logging.info(f"Saving {symbol} financial statement as {filename}.")
     else:
-        return __return_json(path=path, query_vars=query_vars)
+        return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def balance_sheet_statement(
@@ -185,11 +179,11 @@ def balance_sheet_statement(
     query_vars = {"apikey": apikey, "limit": limit, "period": __validate_period(period)}
     if download:
         query_vars["datatype"] = "csv"  # Only CSV is supported.
-        response = requests.get(f"{BASE_URL}{path}", params=query_vars)
+        response = requests.get(f"{BASE_URL_v3}{path}", params=query_vars)
         open(filename, "wb").write(response.content)
         logging.info(f"Saving {symbol} financial statement as {filename}.")
     else:
-        return __return_json(path=path, query_vars=query_vars)
+        return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def cash_flow_statement(
@@ -216,14 +210,16 @@ def cash_flow_statement(
     query_vars = {"apikey": apikey, "limit": limit, "period": __validate_period(period)}
     if download:
         query_vars["datatype"] = "csv"  # Only CSV is supported.
-        response = requests.get(f"{BASE_URL}{path}", params=query_vars)
+        response = requests.get(f"{BASE_URL_v3}{path}", params=query_vars)
         open(filename, "wb").write(response.content)
         logging.info(f"Saving {symbol} financial statement as {filename}.")
     else:
-        return __return_json(path=path, query_vars=query_vars)
+        return __return_json_v3(path=path, query_vars=query_vars)
 
 
-def financial_statement_symbol_lists(apikey: str) -> typing.List[typing.Dict]:
+def financial_statement_symbol_lists(
+    apikey: str,
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /financial-statement-symbol-lists/ API.
 
@@ -233,12 +229,14 @@ def financial_statement_symbol_lists(apikey: str) -> typing.List[typing.Dict]:
     """
     path = f"financial-statement-symbol-lists"
     query_vars = {"apikey": apikey}
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def income_statement_growth(
-    apikey: str, symbol: str, limit: int = DEFAULT_LIMIT,
-) -> typing.List[typing.Dict]:
+    apikey: str,
+    symbol: str,
+    limit: int = DEFAULT_LIMIT,
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /income-statement-growth/ API.
 
@@ -253,12 +251,12 @@ def income_statement_growth(
         "apikey": apikey,
         "limit": limit,
     }
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def balance_sheet_statement_growth(
     apikey: str, symbol: str, limit: int = DEFAULT_LIMIT
-) -> typing.List[typing.Dict]:
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /balance-sheet-statement-growth/ API.
 
@@ -273,12 +271,12 @@ def balance_sheet_statement_growth(
         "apikey": apikey,
         "limit": limit,
     }
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def cash_flow_statement_growth(
     apikey: str, symbol: str, limit: int = DEFAULT_LIMIT
-) -> typing.List[typing.Dict]:
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /cash-flow-statement-growth/ API.
 
@@ -293,7 +291,7 @@ def cash_flow_statement_growth(
         "apikey": apikey,
         "limit": limit,
     }
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def income_statement_as_reported(
@@ -324,11 +322,11 @@ def income_statement_as_reported(
     }
     if download:
         query_vars["datatype"] = "csv"  # Only CSV is supported.
-        response = requests.get(f"{BASE_URL}{path}", params=query_vars)
+        response = requests.get(f"{BASE_URL_v3}{path}", params=query_vars)
         open(filename, "wb").write(response.content)
         logging.info(f"Saving {symbol} financial statement as {filename}.")
     else:
-        return __return_json(path=path, query_vars=query_vars)
+        return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def balance_sheet_statement_as_reported(
@@ -359,11 +357,11 @@ def balance_sheet_statement_as_reported(
     }
     if download:
         query_vars["datatype"] = "csv"  # Only CSV is supported.
-        response = requests.get(f"{BASE_URL}{path}", params=query_vars)
+        response = requests.get(f"{BASE_URL_v3}{path}", params=query_vars)
         open(filename, "wb").write(response.content)
         logging.info(f"Saving {symbol} financial statement as {filename}.")
     else:
-        return __return_json(path=path, query_vars=query_vars)
+        return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def cash_flow_statement_as_reported(
@@ -394,16 +392,18 @@ def cash_flow_statement_as_reported(
     }
     if download:
         query_vars["datatype"] = "csv"  # Only CSV is supported.
-        response = requests.get(f"{BASE_URL}{path}", params=query_vars)
+        response = requests.get(f"{BASE_URL_v3}{path}", params=query_vars)
         open(filename, "wb").write(response.content)
         logging.info(f"Saving {symbol} financial statement as {filename}.")
     else:
-        return __return_json(path=path, query_vars=query_vars)
+        return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def financial_statement_full_as_reported(
-    apikey: str, symbol: str, period: str = "annual",
-) -> typing.List[typing.Dict]:
+    apikey: str,
+    symbol: str,
+    period: str = "annual",
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /financial-statement-full-as-reported/ API.
 
@@ -415,10 +415,12 @@ def financial_statement_full_as_reported(
     """
     path = f"financial-statement-full-as-reported/{symbol}"
     query_vars = {"apikey": apikey, "period": __validate_period(value=period)}
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
-def financial_ratios_ttm(apikey: str, symbol: str) -> typing.List[typing.Dict]:
+def financial_ratios_ttm(
+    apikey: str, symbol: str
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FmP /ratios-ttm/ API.
 
@@ -428,12 +430,15 @@ def financial_ratios_ttm(apikey: str, symbol: str) -> typing.List[typing.Dict]:
     """
     path = f"ratios-ttm/{symbol}"
     query_vars = {"apikey": apikey}
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def financial_ratios(
-    apikey: str, symbol: str, period: str = "annual", limit: int = DEFAULT_LIMIT,
-) -> typing.List[typing.Dict]:
+    apikey: str,
+    symbol: str,
+    period: str = "annual",
+    limit: int = DEFAULT_LIMIT,
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FmP /ratios/ API.
 
@@ -449,12 +454,15 @@ def financial_ratios(
         "limit": limit,
         "period": __validate_period(value=period),
     }
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def enterprise_values(
-    apikey: str, symbol: str, period: str = "annual", limit: int = DEFAULT_LIMIT,
-) -> typing.List[typing.Dict]:
+    apikey: str,
+    symbol: str,
+    period: str = "annual",
+    limit: int = DEFAULT_LIMIT,
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /enterprise-values/ API.
 
@@ -470,12 +478,14 @@ def enterprise_values(
         "limit": limit,
         "period": __validate_period(value=period),
     }
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def key_metrics_ttm(
-    apikey: str, symbol: str, limit: int = DEFAULT_LIMIT,
-) -> typing.List[typing.Dict]:
+    apikey: str,
+    symbol: str,
+    limit: int = DEFAULT_LIMIT,
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /key-metrics-ttm/ API
 
@@ -486,12 +496,15 @@ def key_metrics_ttm(
     """
     path = f"key-metrics-ttm/{symbol}"
     query_vars = {"apikey": apikey, "limit": limit}
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def key_metrics(
-    apikey: str, symbol: str, period: str = "annual", limit: int = DEFAULT_LIMIT,
-) -> typing.List[typing.Dict]:
+    apikey: str,
+    symbol: str,
+    period: str = "annual",
+    limit: int = DEFAULT_LIMIT,
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /key-metrics/ API
 
@@ -507,12 +520,15 @@ def key_metrics(
         "limit": limit,
         "period": __validate_period(value=period),
     }
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def financial_growth(
-    apikey: str, symbol: str, period: str = "annual", limit: int = DEFAULT_LIMIT,
-) -> typing.List[typing.Dict]:
+    apikey: str,
+    symbol: str,
+    period: str = "annual",
+    limit: int = DEFAULT_LIMIT,
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /financial-growth/ API.
 
@@ -528,10 +544,10 @@ def financial_growth(
         "limit": limit,
         "period": __validate_period(value=period),
     }
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
-def rating(apikey: str, symbol: str) -> typing.List[typing.Dict]:
+def rating(apikey: str, symbol: str) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /rating/ API.
 
@@ -541,12 +557,14 @@ def rating(apikey: str, symbol: str) -> typing.List[typing.Dict]:
     """
     path = f"rating/{symbol}"
     query_vars = {"apikey": apikey}
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def historical_rating(
-    apikey: str, symbol: str, limit: int = DEFAULT_LIMIT,
-) -> typing.List[typing.Dict]:
+    apikey: str,
+    symbol: str,
+    limit: int = DEFAULT_LIMIT,
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /financial-growth/ API.
 
@@ -557,10 +575,12 @@ def historical_rating(
     """
     path = f"financial-growth/{symbol}"
     query_vars = {"apikey": apikey, "limit": limit}
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
-def discounted_cash_flow(apikey: str, symbol: str) -> typing.List[typing.Dict]:
+def discounted_cash_flow(
+    apikey: str, symbol: str
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /discounted-cash-flow/ API.
 
@@ -570,12 +590,15 @@ def discounted_cash_flow(apikey: str, symbol: str) -> typing.List[typing.Dict]:
     """
     path = f"discounted-cash-flow/{symbol}"
     query_vars = {"apikey": apikey}
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def historical_discounted_cash_flow(
-    apikey: str, symbol: str, period: str = "annual", limit: int = DEFAULT_LIMIT,
-) -> typing.List[typing.Dict]:
+    apikey: str,
+    symbol: str,
+    period: str = "annual",
+    limit: int = DEFAULT_LIMIT,
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /historical-discounted-cash-flow/ API.
 
@@ -591,12 +614,12 @@ def historical_discounted_cash_flow(
         "limit": limit,
         "period": __validate_period(value=period),
     }
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def historical_daily_discounted_cash_flow(
     apikey: str, symbol: str, limit: int = DEFAULT_LIMIT
-) -> typing.List[typing.Dict]:
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /historical-daily-discounted-cash-flow/ API.
 
@@ -607,10 +630,12 @@ def historical_daily_discounted_cash_flow(
     """
     path = f"historical-daily-discounted-cash-flow/{symbol}"
     query_vars = {"apikey": apikey, "limit": limit}
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
-def market_capitalization(apikey: str, symbol: str) -> typing.List[typing.Dict]:
+def market_capitalization(
+    apikey: str, symbol: str
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /market-capitalization/ API.
 
@@ -620,12 +645,12 @@ def market_capitalization(apikey: str, symbol: str) -> typing.List[typing.Dict]:
     """
     path = f"market-capitalization/{symbol}"
     query_vars = {"apikey": apikey}
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def historical_market_capitalization(
     apikey: str, symbol: str, limit: int = DEFAULT_LIMIT
-) -> typing.List[typing.Dict]:
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /historical-market-capitalization/ API.
 
@@ -636,10 +661,10 @@ def historical_market_capitalization(
     """
     path = f"historical-market-capitalization/{symbol}"
     query_vars = {"apikey": apikey, "limit": limit}
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
-def symbols_list(apikey: str) -> typing.List[typing.Dict]:
+def symbols_list(apikey: str) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /stock/list/ API
 
@@ -648,24 +673,57 @@ def symbols_list(apikey: str) -> typing.List[typing.Dict]:
     """
     path = f"stock/list"
     query_vars = {"apikey": apikey}
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
+
+
+def etf_list(apikey: str) -> typing.Optional[typing.List[typing.Dict]]:
+    """
+    Query FMP /etf/list/ API
+
+    All ETF symbols
+
+    :param apikey: Your API key.
+    :return: A list of dictionaries.
+    """
+    path = f"etf/list"
+    query_vars = {"apikey": apikey}
+    return __return_json_v3(path=path, query_vars=query_vars)
+
+
+def available_traded_list(apikey: str) -> typing.Optional[typing.List[typing.Dict]]:
+    """
+    Query FMP /available-traded/list/ API
+
+    All tradable symbols
+
+    :param apikey: Your API key.
+    :return: A list of dictionaries.
+    """
+    path = f"available-traded/list"
+    query_vars = {"apikey": apikey}
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def stock_screener(
     apikey: str,
-    market_cap_more_than: int = None,
-    market_cap_lower_than: int = None,
-    beta_more_than: int = None,
-    beta_lower_than: int = None,
-    volume_more_than: int = None,
-    volume_lower_than: int = None,
-    dividend_more_than: int = None,
-    dividend_lower_than: int = None,
+    market_cap_more_than: typing.Union[float, int] = None,
+    market_cap_lower_than: typing.Union[float, int] = None,
+    beta_more_than: typing.Union[float, int] = None,
+    beta_lower_than: typing.Union[float, int] = None,
+    volume_more_than: typing.Union[float, int] = None,
+    volume_lower_than: typing.Union[float, int] = None,
+    dividend_more_than: typing.Union[float, int] = None,
+    dividend_lower_than: typing.Union[float, int] = None,
+    price_more_than: typing.Union[float, int] = None,
+    price_lower_than: typing.Union[float, int] = None,
+    is_etf: bool = None,
+    is_actively_trading: bool = None,
     sector: str = None,
     industry: str = None,
+    country: str = None,
     exchange: typing.Union[str, typing.List[str]] = None,
     limit: int = DEFAULT_LIMIT,
-) -> typing.List[typing.Dict]:
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /stock-screener/ API.
 
@@ -678,8 +736,15 @@ def stock_screener(
     :param volume_lower_than:  Numeric Value
     :param dividend_more_than:  Numeric Value
     :param dividend_lower_than:  Numeric Value
+    :param price_more_than: Numeric Value
+    :param price_lower_than: Numeric Value
+    :param price_more_than: Numeric Value
+    :param price_lower_than: Numeric Value
+    :param is_etf: bool
+    :param is_actively_trading: bool
     :param sector: Valid sector name.
     :param industry: Valid industry name.
+    :param country: 2 digit country code as string.
     :param exchange: Stock exchange symbol.
     :param limit: Number of rows to return.
     :return: A list of dicitonaries.
@@ -702,25 +767,36 @@ def stock_screener(
         query_vars["dividendMoreThan"] = dividend_more_than
     if dividend_lower_than:
         query_vars["dividendLowerThan"] = dividend_lower_than
+    if price_more_than:
+        query_vars["priceMoreThan"] = price_more_than
+    if price_lower_than:
+        query_vars["priceLowerThan"] = price_lower_than
+    if is_etf:
+        query_vars["isEtf"] = is_etf
+    if is_actively_trading:
+        query_vars["isActivelyTrading"] = is_actively_trading
     if sector:
         query_vars["sector"] = __validate_sector(sector)
     if industry:
         query_vars["industry"] = __validate_industry(industry)
+    if country:
+        query_vars["country"] = country
     if exchange:
         if type(exchange) is list:
             for item in exchange:
                 if item != __validate_exchange(item):
-                    logging.error(f"Invalid Exchange value: {exchange}.")
-                    exit(1)
+                    msg = f"Invalid Exchange value: {exchange}."
+                    logging.error(msg)
+                    raise ValueError(msg)
             query_vars["exchange"] = ",".join(exchange)
         else:
             query_vars["exchange"] = __validate_exchange(exchange)
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def delisted_companies(
     apikey: str, limit: int = DEFAULT_LIMIT
-) -> typing.List[typing.Dict]:
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /delisted-companies/ API.
 
@@ -729,15 +805,15 @@ def delisted_companies(
     :return: A list of dictionaries.
     """
     path = f"delisted-companies"
-    query_vars = {"apikey": apikey, "limt": limit}
-    return __return_json(path=path, query_vars=query_vars)
+    query_vars = {"apikey": apikey, "limit": limit}
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def stock_news(
     apikey: str,
     tickers: typing.Union[str, typing.List] = "",
     limit: int = DEFAULT_LIMIT,
-) -> typing.List[typing.Dict]:
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /stock_news/ API.
 
@@ -747,15 +823,17 @@ def stock_news(
     :return: A list of dictionaries.
     """
     path = f"stock_news"
-    query_vars = {"apikey": apikey, "limt": limit}
+    query_vars = {"apikey": apikey, "limit": limit}
     if tickers:
         if type(tickers) is list:
             tickers = ",".join(tickers)
         query_vars["tickers"] = tickers
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
-def earnings_surprises(apikey: str, symbol: str) -> typing.List[typing.Dict]:
+def earnings_surprises(
+    apikey: str, symbol: str
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /earnings-surprises/ API.
 
@@ -765,12 +843,60 @@ def earnings_surprises(apikey: str, symbol: str) -> typing.List[typing.Dict]:
     """
     path = f"earnings-surprises/{symbol}"
     query_vars = {"apikey": apikey}
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
+
+
+def earning_call_transcript(
+    apikey: str, symbol: str, year: int, quarter: int
+) -> typing.Optional[typing.List[typing.Dict]]:
+    """
+    Query FMP /earning_call_transcript/ API.
+
+    :param apikey: Your API key.
+    :param symbol: Company ticker.
+    :param year: Year of the transcripts
+    :param quarter: Quarter of the transcripts
+    :return: A list of dictionaries.
+    """
+    path = f"earning_call_transcript/{symbol}"
+    query_vars = {"apikey": apikey, "year": year, "quarter": quarter}
+    return __return_json_v3(path=path, query_vars=query_vars)
+
+
+def batch_earning_call_transcript(
+    apikey: str, symbol: str, year: int
+) -> typing.Optional[typing.List[typing.Dict]]:
+    """
+    Query FMP /batch_earning_call_transcript/ API.
+
+    :param apikey: Your API key.
+    :param symbol: Company ticker.
+    :param year: Year of the transcripts
+    :return: A list of dictionaries.
+    """
+    path = f"batch_earning_call_transcript/{symbol}"
+    query_vars = {"apikey": apikey, "year": year}
+    return __return_json_v4(path=path, query_vars=query_vars)
+
+
+def earning_call_transcripts_available_dates(
+    apikey: str, symbol: str
+) -> typing.Optional[typing.List[typing.List]]:
+    """
+    Query FMP /earning_call_transcript/ API.
+
+    :param apikey: Your API key.
+    :param symbol: Company ticker.
+    :return: A list of lists.
+    """
+    path = f"earning_call_transcript"
+    query_vars = {"apikey": apikey, "symbol": symbol}
+    return __return_json_v4(path=path, query_vars=query_vars)
 
 
 def sec_filings(
     apikey: str, symbol: str, filing_type: str = "", limit: int = DEFAULT_LIMIT
-) -> typing.List[typing.Dict]:
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /sec_filings/ API.
 
@@ -782,12 +908,12 @@ def sec_filings(
     """
     path = f"sec_filings/{symbol}"
     query_vars = {"apikey": apikey, "type": filing_type, "limit": limit}
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
 
 
 def press_releases(
     apikey: str, symbol: str, limit: int = DEFAULT_LIMIT
-) -> typing.List[typing.Dict]:
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /press-releases/ API.
 
@@ -798,4 +924,4 @@ def press_releases(
     """
     path = f"press-releases/{symbol}"
     query_vars = {"apikey": apikey, "limit": limit}
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
